==> zzyj-outputvalcount-api-3.0.0-20230308.074201-154-sources.jar: com/ejianc/business/outputvalcount/vo/EmployeeReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * EmployeeReportVO
 * 人员任职情况报表ES页面VO对象
 */
public class EmployeeReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long billId;//主键id
    private Long emId;//
    private Long orgId;//
    private String emName;//姓名
    private String orgName;//单位名称
    private Long postId;//
    private String postName;//岗位
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date jobsTime;//任职开始
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date jobeTime;//任职结束
    private Long curState;//
    private String curStateName;//在岗情况
    private String propertyName;//兼职情况
    private Long zorgId;//
    private String zorgName;//	主任职单位
    private Long userID;//
    private String emCode;//
    private String mobile;//联系电话
    private Long eType;//
    private String eTypeName;//人员类型
    private String url;//跳转人力系统链接
    private String exType;
    private String exTypeName;//工作属性
    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }

    public Long getEmId() {
        return emId;
    }

    public void setEmId(Long emId) {
        this.emId = emId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getEmName() {
        return emName;
    }

    public void setEmName(String emName) {
        this.emName = emName;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public Date getJobsTime() {
        return jobsTime;
    }

    public void setJobsTime(Date jobsTime) {
        this.jobsTime = jobsTime;
    }

    public Date getJobeTime() {
        return jobeTime;
    }

    public void setJobeTime(Date jobeTime) {
        this.jobeTime = jobeTime;
    }

    public Long getCurState() {
        return curState;
    }

    public void setCurState(Long curState) {
        this.curState = curState;
    }

    public String getCurStateName() {
        return curStateName;
    }

    public void setCurStateName(String curStateName) {
        this.curStateName = curStateName;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public Long getZorgId() {
        return zorgId;
    }

    public void setZorgId(Long zorgId) {
        this.zorgId = zorgId;
    }

    public String getZorgName() {
        return zorgName;
    }

    public void setZorgName(String zorgName) {
        this.zorgName = zorgName;
    }

    public Long getUserID() {
        return userID;
    }

    public void setUserID(Long userID) {
        this.userID = userID;
    }

    public String getEmCode() {
        return emCode;
    }

    public void setEmCode(String emCode) {
        this.emCode = emCode;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Long geteType() {
        return eType;
    }

    public void seteType(Long eType) {
        this.eType = eType;
    }

    public String geteTypeName() {
        return eTypeName;
    }

    public void seteTypeName(String eTypeName) {
        this.eTypeName = eTypeName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getExType() {
        return exType;
    }

    public void setExType(String exType) {
        this.exType = exType;
    }

    public String getExTypeName() {
        return exTypeName;
    }

    public void setExTypeName(String exTypeName) {
        this.exTypeName = exTypeName;
    }
}

==> zzyj-outputvalcount-api-3.0.0-20230810.084943-220-sources.jar: com/ejianc/business/outputvalcount/vo/EmployeeReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * EmployeeReportVO
 * 人员任职情况报表ES页面VO对象
 */
public class EmployeeReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long billId;//主键id
    private Long emId;//
    private Long orgId;//
    private String emName;//姓名
    private String orgName;//单位名称
    private Long postId;//
    private String postName;//岗位
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date jobsTime;//任职开始
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date jobeTime;//任职结束
    private Long curState;//
    private String curStateName;//在岗情况
    private String propertyName;//兼职情况
    private Long zorgId;//
    private String zorgName;//	主任职单位
    private Long userID;//
    private String emCode;//
    private String mobile;//联系电话
    private Long eType;//
    private String eTypeName;//人员类型
    private String url;//跳转人力系统链接
    private String exType;
    private String exTypeName;//工作属性
    private Long postCode;//岗位编号
    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }

    public Long getEmId() {
        return emId;
    }

    public void setEmId(Long emId) {
        this.emId = emId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getEmName() {
        return emName;
    }

    public void setEmName(String emName) {
        this.emName = emName;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public Date getJobsTime() {
        return jobsTime;
    }

    public void setJobsTime(Date jobsTime) {
        this.jobsTime = jobsTime;
    }

    public Date getJobeTime() {
        return jobeTime;
    }

    public void setJobeTime(Date jobeTime) {
        this.jobeTime = jobeTime;
    }

    public Long getCurState() {
        return curState;
    }

    public void setCurState(Long curState) {
        this.curState = curState;
    }

    public String getCurStateName() {
        return curStateName;
    }

    public void setCurStateName(String curStateName) {
        this.curStateName = curStateName;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public Long getZorgId() {
        return zorgId;
    }

    public void setZorgId(Long zorgId) {
        this.zorgId = zorgId;
    }

    public String getZorgName() {
        return zorgName;
    }

    public void setZorgName(String zorgName) {
        this.zorgName = zorgName;
    }

    public Long getUserID() {
        return userID;
    }

    public void setUserID(Long userID) {
        this.userID = userID;
    }

    public String getEmCode() {
        return emCode;
    }

    public void setEmCode(String emCode) {
        this.emCode = emCode;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Long geteType() {
        return eType;
    }

    public void seteType(Long eType) {
        this.eType = eType;
    }

    public String geteTypeName() {
        return eTypeName;
    }

    public void seteTypeName(String eTypeName) {
        this.eTypeName = eTypeName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getExType() {
        return exType;
    }

    public void setExType(String exType) {
        this.exType = exType;
    }

    public String getExTypeName() {
        return exTypeName;
    }

    public void setExTypeName(String exTypeName) {
        this.exTypeName = exTypeName;
    }

    public Long getPostCode() {
        return postCode;
    }

    public void setPostCode(Long postCode) {
        this.postCode = postCode;
    }
}
